Rename static analyzer namespace 'GR' to 'ento'.

git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@122492 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/include/clang/Analysis/DomainSpecific/CocoaConventions.h b/include/clang/Analysis/DomainSpecific/CocoaConventions.h
index 0212cbf..18e81fe 100644
--- a/include/clang/Analysis/DomainSpecific/CocoaConventions.h
+++ b/include/clang/Analysis/DomainSpecific/CocoaConventions.h
@@ -17,7 +17,7 @@
 #include "clang/AST/Type.h"
 
 namespace clang {
-namespace GR {
+namespace ento {
 namespace cocoa {
  
   enum NamingConvention { NoConvention, CreateRule, InitRule };
diff --git a/include/clang/GR/AnalysisConsumer.h b/include/clang/GR/AnalysisConsumer.h
index 8056388..86f6c72 100644
--- a/include/clang/GR/AnalysisConsumer.h
+++ b/include/clang/GR/AnalysisConsumer.h
@@ -23,7 +23,7 @@
 class ASTConsumer;
 class Preprocessor;
 
-namespace GR {
+namespace ento {
 
 /// CreateAnalysisConsumer - Creates an ASTConsumer to run various code
 /// analysis passes.  (The set of analyses run is controlled by command-line
diff --git a/include/clang/GR/BugReporter/BugReporter.h b/include/clang/GR/BugReporter/BugReporter.h
index 31487b6..7d2dffa 100644
--- a/include/clang/GR/BugReporter/BugReporter.h
+++ b/include/clang/GR/BugReporter/BugReporter.h
@@ -30,7 +30,7 @@
 class Stmt;
 class ParentMap;
 
-namespace GR {
+namespace ento {
 
 class PathDiagnostic;
 class PathDiagnosticPiece;
diff --git a/include/clang/GR/BugReporter/BugType.h b/include/clang/GR/BugReporter/BugType.h
index a18e596..8540949 100644
--- a/include/clang/GR/BugReporter/BugType.h
+++ b/include/clang/GR/BugReporter/BugType.h
@@ -20,7 +20,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 class ExplodedNode;
 class ExprEngine;
diff --git a/include/clang/GR/BugReporter/PathDiagnostic.h b/include/clang/GR/BugReporter/PathDiagnostic.h
index c19bb75..6d53c09 100644
--- a/include/clang/GR/BugReporter/PathDiagnostic.h
+++ b/include/clang/GR/BugReporter/PathDiagnostic.h
@@ -27,7 +27,7 @@
 class SourceManager;
 class Stmt;
 
-namespace GR {
+namespace ento {
 
 //===----------------------------------------------------------------------===//
 // High-level interface for handlers of path-sensitive diagnostics.
diff --git a/include/clang/GR/Checkers/DereferenceChecker.h b/include/clang/GR/Checkers/DereferenceChecker.h
index 2ac45bf..f9cce9c 100644
--- a/include/clang/GR/Checkers/DereferenceChecker.h
+++ b/include/clang/GR/Checkers/DereferenceChecker.h
@@ -20,7 +20,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 class ExprEngine;
 class ExplodedNode;
diff --git a/include/clang/GR/Checkers/LocalCheckers.h b/include/clang/GR/Checkers/LocalCheckers.h
index d9352ee..e0f002b 100644
--- a/include/clang/GR/Checkers/LocalCheckers.h
+++ b/include/clang/GR/Checkers/LocalCheckers.h
@@ -28,7 +28,7 @@
 class LangOptions;
 class TranslationUnitDecl;
 
-namespace GR {
+namespace ento {
 
 class PathDiagnosticClient;
 class TransferFuncs;
diff --git a/include/clang/GR/FrontendActions.h b/include/clang/GR/FrontendActions.h
index dd4a549..e3867a2 100644
--- a/include/clang/GR/FrontendActions.h
+++ b/include/clang/GR/FrontendActions.h
@@ -14,7 +14,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 //===----------------------------------------------------------------------===//
 // AST Consumer Actions
diff --git a/include/clang/GR/ManagerRegistry.h b/include/clang/GR/ManagerRegistry.h
index 30c487d..ff174c0 100644
--- a/include/clang/GR/ManagerRegistry.h
+++ b/include/clang/GR/ManagerRegistry.h
@@ -18,7 +18,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 /// ManagerRegistry - This class records manager creators registered at
 /// runtime. The information is communicated to AnalysisManager through static
diff --git a/include/clang/GR/PathDiagnosticClients.h b/include/clang/GR/PathDiagnosticClients.h
index 612dfb1..2713e31 100644
--- a/include/clang/GR/PathDiagnosticClients.h
+++ b/include/clang/GR/PathDiagnosticClients.h
@@ -20,7 +20,7 @@
 
 class Preprocessor;
 
-namespace GR {
+namespace ento {
 
 class PathDiagnosticClient;
 
diff --git a/include/clang/GR/PathSensitive/AnalysisManager.h b/include/clang/GR/PathSensitive/AnalysisManager.h
index 59bf416..c9deccc 100644
--- a/include/clang/GR/PathSensitive/AnalysisManager.h
+++ b/include/clang/GR/PathSensitive/AnalysisManager.h
@@ -26,7 +26,7 @@
   class TranslationUnit; 
 }
 
-namespace GR {
+namespace ento {
 
 class AnalysisManager : public BugReporterData {
   AnalysisContextManager AnaCtxMgr;
diff --git a/include/clang/GR/PathSensitive/BasicValueFactory.h b/include/clang/GR/PathSensitive/BasicValueFactory.h
index c310408..0a692ba 100644
--- a/include/clang/GR/PathSensitive/BasicValueFactory.h
+++ b/include/clang/GR/PathSensitive/BasicValueFactory.h
@@ -24,7 +24,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
   class GRState;
 
diff --git a/include/clang/GR/PathSensitive/BlockCounter.h b/include/clang/GR/PathSensitive/BlockCounter.h
index 071ccb0..7d0fdfb 100644
--- a/include/clang/GR/PathSensitive/BlockCounter.h
+++ b/include/clang/GR/PathSensitive/BlockCounter.h
@@ -24,7 +24,7 @@
 
 class StackFrameContext;
 
-namespace GR {
+namespace ento {
 
 class BlockCounter {
   void* Data;
diff --git a/include/clang/GR/PathSensitive/Checker.h b/include/clang/GR/PathSensitive/Checker.h
index c1cac57..73fb37f 100644
--- a/include/clang/GR/PathSensitive/Checker.h
+++ b/include/clang/GR/PathSensitive/Checker.h
@@ -24,7 +24,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 class CheckerContext {
   ExplodedNodeSet &Dst;
diff --git a/include/clang/GR/PathSensitive/CheckerHelpers.h b/include/clang/GR/PathSensitive/CheckerHelpers.h
index 7afd67d..005e0e5 100644
--- a/include/clang/GR/PathSensitive/CheckerHelpers.h
+++ b/include/clang/GR/PathSensitive/CheckerHelpers.h
@@ -18,7 +18,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 bool containsMacro(const Stmt *S);
 bool containsEnum(const Stmt *S);
diff --git a/include/clang/GR/PathSensitive/CheckerVisitor.h b/include/clang/GR/PathSensitive/CheckerVisitor.h
index 26f85d7..18ffa9f 100644
--- a/include/clang/GR/PathSensitive/CheckerVisitor.h
+++ b/include/clang/GR/PathSensitive/CheckerVisitor.h
@@ -17,7 +17,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 //===----------------------------------------------------------------------===//
 // Checker visitor interface.  Used by subclasses of Checker to specify their
diff --git a/include/clang/GR/PathSensitive/ConstraintManager.h b/include/clang/GR/PathSensitive/ConstraintManager.h
index 0cc023f..3e73f4b 100644
--- a/include/clang/GR/PathSensitive/ConstraintManager.h
+++ b/include/clang/GR/PathSensitive/ConstraintManager.h
@@ -23,7 +23,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 class GRState;
 class GRStateManager;
diff --git a/include/clang/GR/PathSensitive/CoreEngine.h b/include/clang/GR/PathSensitive/CoreEngine.h
index c66d0ba..eaaff52 100644
--- a/include/clang/GR/PathSensitive/CoreEngine.h
+++ b/include/clang/GR/PathSensitive/CoreEngine.h
@@ -24,7 +24,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 //===----------------------------------------------------------------------===//
 /// CoreEngine - Implements the core logic of the graph-reachability
diff --git a/include/clang/GR/PathSensitive/Environment.h b/include/clang/GR/PathSensitive/Environment.h
index 36f26e0..a8861cc 100644
--- a/include/clang/GR/PathSensitive/Environment.h
+++ b/include/clang/GR/PathSensitive/Environment.h
@@ -22,7 +22,7 @@
 
 class LiveVariables;
 
-namespace GR {
+namespace ento {
 
 class EnvironmentManager;
 class SValBuilder;
diff --git a/include/clang/GR/PathSensitive/ExplodedGraph.h b/include/clang/GR/PathSensitive/ExplodedGraph.h
index a185a13..7f8c4c6 100644
--- a/include/clang/GR/PathSensitive/ExplodedGraph.h
+++ b/include/clang/GR/PathSensitive/ExplodedGraph.h
@@ -36,7 +36,7 @@
 
 class CFG;
 
-namespace GR {
+namespace ento {
 
 class GRState;
 class ExplodedGraph;
@@ -378,8 +378,8 @@
 // GraphTraits
 
 namespace llvm {
-  template<> struct GraphTraits<clang::GR::ExplodedNode*> {
-    typedef clang::GR::ExplodedNode NodeType;
+  template<> struct GraphTraits<clang::ento::ExplodedNode*> {
+    typedef clang::ento::ExplodedNode NodeType;
     typedef NodeType::succ_iterator  ChildIteratorType;
     typedef llvm::df_iterator<NodeType*>      nodes_iterator;
 
@@ -404,8 +404,8 @@
     }
   };
 
-  template<> struct GraphTraits<const clang::GR::ExplodedNode*> {
-    typedef const clang::GR::ExplodedNode NodeType;
+  template<> struct GraphTraits<const clang::ento::ExplodedNode*> {
+    typedef const clang::ento::ExplodedNode NodeType;
     typedef NodeType::const_succ_iterator   ChildIteratorType;
     typedef llvm::df_iterator<NodeType*>       nodes_iterator;
 
diff --git a/include/clang/GR/PathSensitive/ExprEngine.h b/include/clang/GR/PathSensitive/ExprEngine.h
index c61c251..ed06b27 100644
--- a/include/clang/GR/PathSensitive/ExprEngine.h
+++ b/include/clang/GR/PathSensitive/ExprEngine.h
@@ -31,7 +31,7 @@
 
 class ObjCForCollectionStmt;
 
-namespace GR {
+namespace ento {
 
 class AnalysisManager;
 class Checker;
diff --git a/include/clang/GR/PathSensitive/ExprEngineBuilders.h b/include/clang/GR/PathSensitive/ExprEngineBuilders.h
index e6af5a8..b3ccc29 100644
--- a/include/clang/GR/PathSensitive/ExprEngineBuilders.h
+++ b/include/clang/GR/PathSensitive/ExprEngineBuilders.h
@@ -19,7 +19,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 class StmtNodeBuilderRef {
   ExplodedNodeSet &Dst;
diff --git a/include/clang/GR/PathSensitive/GRState.h b/include/clang/GR/PathSensitive/GRState.h
index f540fd2..914dadb 100644
--- a/include/clang/GR/PathSensitive/GRState.h
+++ b/include/clang/GR/PathSensitive/GRState.h
@@ -31,7 +31,7 @@
 namespace clang {
 class ASTContext;
 
-namespace GR {
+namespace ento {
 
 class GRStateManager;
 class Checker;
diff --git a/include/clang/GR/PathSensitive/GRStateTrait.h b/include/clang/GR/PathSensitive/GRStateTrait.h
index 5c17392..914625a 100644
--- a/include/clang/GR/PathSensitive/GRStateTrait.h
+++ b/include/clang/GR/PathSensitive/GRStateTrait.h
@@ -27,7 +27,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
   template <typename T> struct GRStatePartialTrait;
 
   // Partial-specialization for ImmutableMap.
diff --git a/include/clang/GR/PathSensitive/MemRegion.h b/include/clang/GR/PathSensitive/MemRegion.h
index 59e8060..20e25cf 100644
--- a/include/clang/GR/PathSensitive/MemRegion.h
+++ b/include/clang/GR/PathSensitive/MemRegion.h
@@ -34,7 +34,7 @@
 class LocationContext;
 class StackFrameContext;
 
-namespace GR {
+namespace ento {
 
 class MemRegionManager;
 class MemSpaceRegion;
@@ -1068,7 +1068,7 @@
 
 namespace llvm {
 static inline raw_ostream& operator<<(raw_ostream& os,
-                                      const clang::GR::MemRegion* R) {
+                                      const clang::ento::MemRegion* R) {
   R->dumpToStream(os);
   return os;
 }
diff --git a/include/clang/GR/PathSensitive/SValBuilder.h b/include/clang/GR/PathSensitive/SValBuilder.h
index 9578025..b01f430 100644
--- a/include/clang/GR/PathSensitive/SValBuilder.h
+++ b/include/clang/GR/PathSensitive/SValBuilder.h
@@ -23,7 +23,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 class GRState;
 
diff --git a/include/clang/GR/PathSensitive/Store.h b/include/clang/GR/PathSensitive/Store.h
index 446ea08..f82959b 100644
--- a/include/clang/GR/PathSensitive/Store.h
+++ b/include/clang/GR/PathSensitive/Store.h
@@ -26,7 +26,7 @@
 class ObjCIvarDecl;
 class StackFrameContext;
 
-namespace GR {
+namespace ento {
 
 /// Store - This opaque type encapsulates an immutable mapping from
 ///  locations to values.  At a high-level, it represents the symbolic
diff --git a/include/clang/GR/PathSensitive/SubEngine.h b/include/clang/GR/PathSensitive/SubEngine.h
index 0539e7a..755dff7 100644
--- a/include/clang/GR/PathSensitive/SubEngine.h
+++ b/include/clang/GR/PathSensitive/SubEngine.h
@@ -22,7 +22,7 @@
 class LocationContext;
 class Stmt;
 
-namespace GR {
+namespace ento {
 
 class AnalysisManager;
 class ExplodedNode;
diff --git a/include/clang/GR/PathSensitive/SummaryManager.h b/include/clang/GR/PathSensitive/SummaryManager.h
index 8f01ce2..ed87851 100644
--- a/include/clang/GR/PathSensitive/SummaryManager.h
+++ b/include/clang/GR/PathSensitive/SummaryManager.h
@@ -20,7 +20,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 namespace summMgr {
 
diff --git a/include/clang/GR/PathSensitive/SymbolManager.h b/include/clang/GR/PathSensitive/SymbolManager.h
index cab3505..ad173bb 100644
--- a/include/clang/GR/PathSensitive/SymbolManager.h
+++ b/include/clang/GR/PathSensitive/SymbolManager.h
@@ -31,7 +31,7 @@
   class ASTContext;
   class StackFrameContext;
 
-namespace GR {
+namespace ento {
   class BasicValueFactory;
   class MemRegion;
   class SubRegion;
@@ -481,7 +481,7 @@
 
 namespace llvm {
 static inline llvm::raw_ostream& operator<<(llvm::raw_ostream& os,
-                                            const clang::GR::SymExpr *SE) {
+                                            const clang::ento::SymExpr *SE) {
   SE->dumpToStream(os);
   return os;
 }
diff --git a/include/clang/GR/PathSensitive/TransferFuncs.h b/include/clang/GR/PathSensitive/TransferFuncs.h
index 10f46c4..c73a33d 100644
--- a/include/clang/GR/PathSensitive/TransferFuncs.h
+++ b/include/clang/GR/PathSensitive/TransferFuncs.h
@@ -22,7 +22,7 @@
 namespace clang {
 class ObjCMessageExpr;
 
-namespace GR {
+namespace ento {
 class ExplodedNode;
 class ExplodedNodeSet;
 class EndPathNodeBuilder;
diff --git a/include/clang/GR/PathSensitive/WorkList.h b/include/clang/GR/PathSensitive/WorkList.h
index 6e35400..132bcf6 100644
--- a/include/clang/GR/PathSensitive/WorkList.h
+++ b/include/clang/GR/PathSensitive/WorkList.h
@@ -22,7 +22,7 @@
   
 class CFGBlock;
 
-namespace GR {
+namespace ento {
 
 class ExplodedNode;
 class ExplodedNodeImpl;
diff --git a/lib/Analysis/CocoaConventions.cpp b/lib/Analysis/CocoaConventions.cpp
index 5fb58de..2c263ca 100644
--- a/lib/Analysis/CocoaConventions.cpp
+++ b/lib/Analysis/CocoaConventions.cpp
@@ -18,7 +18,7 @@
 #include "llvm/ADT/StringExtras.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 using llvm::StringRef;
 
diff --git a/lib/FrontendTool/ExecuteCompilerInvocation.cpp b/lib/FrontendTool/ExecuteCompilerInvocation.cpp
index 84bebf5..ae6194b 100644
--- a/lib/FrontendTool/ExecuteCompilerInvocation.cpp
+++ b/lib/FrontendTool/ExecuteCompilerInvocation.cpp
@@ -80,7 +80,7 @@
   case RewriteMacros:          return new RewriteMacrosAction();
   case RewriteObjC:            return new RewriteObjCAction();
   case RewriteTest:            return new RewriteTestAction();
-  case RunAnalysis:            return new GR::AnalysisAction();
+  case RunAnalysis:            return new ento::AnalysisAction();
   case RunPreprocessorOnly:    return new PreprocessOnlyAction();
   }
 }
diff --git a/lib/GR/AggExprVisitor.cpp b/lib/GR/AggExprVisitor.cpp
index 4502298..af30c56 100644
--- a/lib/GR/AggExprVisitor.cpp
+++ b/lib/GR/AggExprVisitor.cpp
@@ -16,7 +16,7 @@
 #include "clang/AST/StmtVisitor.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 /// AggExprVisitor is designed after AggExprEmitter of the CodeGen module.  It
diff --git a/lib/GR/AnalysisManager.cpp b/lib/GR/AnalysisManager.cpp
index b0942e1..767ae4a 100644
--- a/lib/GR/AnalysisManager.cpp
+++ b/lib/GR/AnalysisManager.cpp
@@ -12,7 +12,7 @@
 #include "clang/Index/Indexer.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 AnalysisContext *
 AnalysisManager::getAnalysisContextInAnotherTU(const Decl *D) {
diff --git a/lib/GR/AnalyzerStatsChecker.cpp b/lib/GR/AnalyzerStatsChecker.cpp
index c60b450..fa8ae59 100644
--- a/lib/GR/AnalyzerStatsChecker.cpp
+++ b/lib/GR/AnalyzerStatsChecker.cpp
@@ -20,7 +20,7 @@
 #include "llvm/ADT/SmallPtrSet.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class AnalyzerStatsChecker : public CheckerVisitor<AnalyzerStatsChecker> {
@@ -38,7 +38,7 @@
   return &x;
 }
 
-void GR::RegisterAnalyzerStatsChecker(ExprEngine &Eng) {
+void ento::RegisterAnalyzerStatsChecker(ExprEngine &Eng) {
   Eng.registerCheck(new AnalyzerStatsChecker());
 }
 
diff --git a/lib/GR/BasicConstraintManager.cpp b/lib/GR/BasicConstraintManager.cpp
index 2de0d9a..da91f5c 100644
--- a/lib/GR/BasicConstraintManager.cpp
+++ b/lib/GR/BasicConstraintManager.cpp
@@ -19,7 +19,7 @@
 #include "llvm/Support/raw_ostream.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 
 namespace { class ConstNotEq {}; }
@@ -32,7 +32,7 @@
 static int ConstNotEqIndex = 0;
 
 namespace clang {
-namespace GR {
+namespace ento {
 template<>
 struct GRStateTrait<ConstNotEq> : public GRStatePartialTrait<ConstNotEqTy> {
   static inline void* GDMIndex() { return &ConstNotEqIndex; }
@@ -98,7 +98,7 @@
 
 } // end anonymous namespace
 
-ConstraintManager* GR::CreateBasicConstraintManager(GRStateManager& statemgr,
+ConstraintManager* ento::CreateBasicConstraintManager(GRStateManager& statemgr,
                                                        SubEngine &subengine) {
   return new BasicConstraintManager(statemgr, subengine);
 }
diff --git a/lib/GR/BasicStore.cpp b/lib/GR/BasicStore.cpp
index 1c8ab11..9eb8d79 100644
--- a/lib/GR/BasicStore.cpp
+++ b/lib/GR/BasicStore.cpp
@@ -19,7 +19,7 @@
 #include "llvm/ADT/ImmutableMap.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 typedef llvm::ImmutableMap<const MemRegion*,SVal> BindingsTy;
 
@@ -104,7 +104,7 @@
 } // end anonymous namespace
 
 
-StoreManager* GR::CreateBasicStoreManager(GRStateManager& StMgr) {
+StoreManager* ento::CreateBasicStoreManager(GRStateManager& StMgr) {
   return new BasicStoreManager(StMgr);
 }
 
diff --git a/lib/GR/BasicValueFactory.cpp b/lib/GR/BasicValueFactory.cpp
index 7e45a15..8e51361 100644
--- a/lib/GR/BasicValueFactory.cpp
+++ b/lib/GR/BasicValueFactory.cpp
@@ -16,7 +16,7 @@
 #include "clang/GR/PathSensitive/BasicValueFactory.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 void CompoundValData::Profile(llvm::FoldingSetNodeID& ID, QualType T,
                               llvm::ImmutableList<SVal> L) {
diff --git a/lib/GR/BlockCounter.cpp b/lib/GR/BlockCounter.cpp
index ee76e7a..dadf707 100644
--- a/lib/GR/BlockCounter.cpp
+++ b/lib/GR/BlockCounter.cpp
@@ -17,7 +17,7 @@
 #include "llvm/ADT/ImmutableMap.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 
diff --git a/lib/GR/BugReporter.cpp b/lib/GR/BugReporter.cpp
index dedbd70..769e2b9 100644
--- a/lib/GR/BugReporter.cpp
+++ b/lib/GR/BugReporter.cpp
@@ -30,7 +30,7 @@
 #include <queue>
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 BugReporterVisitor::~BugReporterVisitor() {}
 BugReporterContext::~BugReporterContext() {
diff --git a/lib/GR/BugReporterVisitors.cpp b/lib/GR/BugReporterVisitors.cpp
index f56d053..78b5ad6 100644
--- a/lib/GR/BugReporterVisitors.cpp
+++ b/lib/GR/BugReporterVisitors.cpp
@@ -20,7 +20,7 @@
 #include "clang/GR/PathSensitive/GRState.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 //===----------------------------------------------------------------------===//
 // Utility functions.
diff --git a/lib/GR/CFRefCount.cpp b/lib/GR/CFRefCount.cpp
index a99019c..2fe6b18 100644
--- a/lib/GR/CFRefCount.cpp
+++ b/lib/GR/CFRefCount.cpp
@@ -34,7 +34,7 @@
 #include <stdarg.h>
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 using llvm::StringRef;
 using llvm::StrInStrNoCase;
 
@@ -397,7 +397,7 @@
 typedef llvm::ImmutableMap<SymbolRef, RefVal> RefBindings;
 
 namespace clang {
-namespace GR {
+namespace ento {
   template<>
   struct GRStateTrait<RefBindings> : public GRStatePartialTrait<RefBindings> {
     static void* GDMIndex() {
@@ -1579,7 +1579,7 @@
 namespace { class AutoreleaseStack {}; }
 
 namespace clang {
-namespace GR {
+namespace ento {
 template<> struct GRStateTrait<AutoreleaseStack>
   : public GRStatePartialTrait<ARStack> {
   static inline void* GDMIndex() { return &AutoRBIndex; }
@@ -3494,7 +3494,7 @@
   Eng.registerCheck(new RetainReleaseChecker(this));
 }
 
-TransferFuncs* GR::MakeCFRefCountTF(ASTContext& Ctx, bool GCEnabled,
+TransferFuncs* ento::MakeCFRefCountTF(ASTContext& Ctx, bool GCEnabled,
                                          const LangOptions& lopts) {
   return new CFRefCount(Ctx, GCEnabled, lopts);
 }
diff --git a/lib/GR/CXXExprEngine.cpp b/lib/GR/CXXExprEngine.cpp
index b1111c9..eee90f2 100644
--- a/lib/GR/CXXExprEngine.cpp
+++ b/lib/GR/CXXExprEngine.cpp
@@ -16,7 +16,7 @@
 #include "clang/AST/DeclCXX.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class CallExprWLItem {
diff --git a/lib/GR/Checker.cpp b/lib/GR/Checker.cpp
index 521d9e2..975d847 100644
--- a/lib/GR/Checker.cpp
+++ b/lib/GR/Checker.cpp
@@ -14,7 +14,7 @@
 
 #include "clang/GR/PathSensitive/Checker.h"
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 Checker::~Checker() {}
 
diff --git a/lib/GR/CheckerHelpers.cpp b/lib/GR/CheckerHelpers.cpp
index 23144a3..81e8339 100644
--- a/lib/GR/CheckerHelpers.cpp
+++ b/lib/GR/CheckerHelpers.cpp
@@ -15,7 +15,7 @@
 #include "clang/AST/Expr.h"
 
 // Recursively find any substatements containing macros
-bool clang::GR::containsMacro(const Stmt *S) {
+bool clang::ento::containsMacro(const Stmt *S) {
   if (S->getLocStart().isMacroID())
     return true;
 
@@ -32,7 +32,7 @@
 }
 
 // Recursively find any substatements containing enum constants
-bool clang::GR::containsEnum(const Stmt *S) {
+bool clang::ento::containsEnum(const Stmt *S) {
   const DeclRefExpr *DR = dyn_cast<DeclRefExpr>(S);
 
   if (DR && isa<EnumConstantDecl>(DR->getDecl()))
@@ -48,7 +48,7 @@
 }
 
 // Recursively find any substatements containing static vars
-bool clang::GR::containsStaticLocal(const Stmt *S) {
+bool clang::ento::containsStaticLocal(const Stmt *S) {
   const DeclRefExpr *DR = dyn_cast<DeclRefExpr>(S);
 
   if (DR)
@@ -66,7 +66,7 @@
 }
 
 // Recursively find any substatements containing __builtin_offsetof
-bool clang::GR::containsBuiltinOffsetOf(const Stmt *S) {
+bool clang::ento::containsBuiltinOffsetOf(const Stmt *S) {
   if (isa<OffsetOfExpr>(S))
     return true;
 
diff --git a/lib/GR/Checkers/AdjustedReturnValueChecker.cpp b/lib/GR/Checkers/AdjustedReturnValueChecker.cpp
index 3c78b39..d4e5389 100644
--- a/lib/GR/Checkers/AdjustedReturnValueChecker.cpp
+++ b/lib/GR/Checkers/AdjustedReturnValueChecker.cpp
@@ -19,7 +19,7 @@
 #include "clang/GR/PathSensitive/CheckerVisitor.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class AdjustedReturnValueChecker : 
@@ -35,7 +35,7 @@
 };
 }
 
-void GR::RegisterAdjustedReturnValueChecker(ExprEngine &Eng) {
+void ento::RegisterAdjustedReturnValueChecker(ExprEngine &Eng) {
   Eng.registerCheck(new AdjustedReturnValueChecker());
 }
 
diff --git a/lib/GR/Checkers/AnalysisConsumer.cpp b/lib/GR/Checkers/AnalysisConsumer.cpp
index 28a260c..f70de05 100644
--- a/lib/GR/Checkers/AnalysisConsumer.cpp
+++ b/lib/GR/Checkers/AnalysisConsumer.cpp
@@ -43,7 +43,7 @@
 #include "llvm/ADT/OwningPtr.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 static ExplodedNode::Auditor* CreateUbiViz();
 
@@ -477,7 +477,7 @@
 // AnalysisConsumer creation.
 //===----------------------------------------------------------------------===//
 
-ASTConsumer* GR::CreateAnalysisConsumer(const Preprocessor& pp,
+ASTConsumer* ento::CreateAnalysisConsumer(const Preprocessor& pp,
                                            const std::string& OutDir,
                                            const AnalyzerOptions& Opts) {
   llvm::OwningPtr<AnalysisConsumer> C(new AnalysisConsumer(pp, OutDir, Opts));
diff --git a/lib/GR/Checkers/ArrayBoundChecker.cpp b/lib/GR/Checkers/ArrayBoundChecker.cpp
index 9dc53a2..9d4e3c4 100644
--- a/lib/GR/Checkers/ArrayBoundChecker.cpp
+++ b/lib/GR/Checkers/ArrayBoundChecker.cpp
@@ -18,7 +18,7 @@
 #include "clang/GR/PathSensitive/ExprEngine.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class ArrayBoundChecker : 
@@ -31,7 +31,7 @@
 };
 }
 
-void GR::RegisterArrayBoundChecker(ExprEngine &Eng) {
+void ento::RegisterArrayBoundChecker(ExprEngine &Eng) {
   Eng.registerCheck(new ArrayBoundChecker());
 }
 
diff --git a/lib/GR/Checkers/ArrayBoundCheckerV2.cpp b/lib/GR/Checkers/ArrayBoundCheckerV2.cpp
index 9a67208..1753ac5 100644
--- a/lib/GR/Checkers/ArrayBoundCheckerV2.cpp
+++ b/lib/GR/Checkers/ArrayBoundCheckerV2.cpp
@@ -19,7 +19,7 @@
 #include "clang/AST/CharUnits.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class ArrayBoundCheckerV2 : 
@@ -62,7 +62,7 @@
 };
 }
 
-void GR::RegisterArrayBoundCheckerV2(ExprEngine &Eng) {
+void ento::RegisterArrayBoundCheckerV2(ExprEngine &Eng) {
   Eng.registerCheck(new ArrayBoundCheckerV2());
 }
 
diff --git a/lib/GR/Checkers/AttrNonNullChecker.cpp b/lib/GR/Checkers/AttrNonNullChecker.cpp
index 74eb882..5c2aede 100644
--- a/lib/GR/Checkers/AttrNonNullChecker.cpp
+++ b/lib/GR/Checkers/AttrNonNullChecker.cpp
@@ -17,7 +17,7 @@
 #include "clang/GR/PathSensitive/CheckerVisitor.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class AttrNonNullChecker
@@ -33,7 +33,7 @@
 };
 } // end anonymous namespace
 
-void GR::RegisterAttrNonNullChecker(ExprEngine &Eng) {
+void ento::RegisterAttrNonNullChecker(ExprEngine &Eng) {
   Eng.registerCheck(new AttrNonNullChecker());
 }
 
diff --git a/lib/GR/Checkers/BasicObjCFoundationChecks.cpp b/lib/GR/Checkers/BasicObjCFoundationChecks.cpp
index 33a58bd..a172477 100644
--- a/lib/GR/Checkers/BasicObjCFoundationChecks.cpp
+++ b/lib/GR/Checkers/BasicObjCFoundationChecks.cpp
@@ -29,7 +29,7 @@
 #include "clang/AST/ASTContext.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class APIMisuse : public BugType {
@@ -511,7 +511,7 @@
 // Check registration.
 //===----------------------------------------------------------------------===//
   
-void GR::RegisterAppleChecks(ExprEngine& Eng, const Decl &D) {
+void ento::RegisterAppleChecks(ExprEngine& Eng, const Decl &D) {
   Eng.registerCheck(new NilArgChecker());
   Eng.registerCheck(new CFNumberCreateChecker());
   RegisterNSErrorChecks(Eng.getBugReporter(), Eng, D);
diff --git a/lib/GR/Checkers/BasicObjCFoundationChecks.h b/lib/GR/Checkers/BasicObjCFoundationChecks.h
index 63143eb..f4966e8 100644
--- a/lib/GR/Checkers/BasicObjCFoundationChecks.h
+++ b/lib/GR/Checkers/BasicObjCFoundationChecks.h
@@ -21,7 +21,7 @@
 class ASTContext;
 class Decl;
 
-namespace GR {
+namespace ento {
 
 class BugReporter;
 class ExprEngine;
diff --git a/lib/GR/Checkers/BuiltinFunctionChecker.cpp b/lib/GR/Checkers/BuiltinFunctionChecker.cpp
index 27162e4..697f0a4 100644
--- a/lib/GR/Checkers/BuiltinFunctionChecker.cpp
+++ b/lib/GR/Checkers/BuiltinFunctionChecker.cpp
@@ -16,7 +16,7 @@
 #include "clang/Basic/Builtins.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 
@@ -28,7 +28,7 @@
 
 }
 
-void GR::RegisterBuiltinFunctionChecker(ExprEngine &Eng) {
+void ento::RegisterBuiltinFunctionChecker(ExprEngine &Eng) {
   Eng.registerCheck(new BuiltinFunctionChecker());
 }
 
diff --git a/lib/GR/Checkers/CStringChecker.cpp b/lib/GR/Checkers/CStringChecker.cpp
index a9d3064..d658c2f 100644
--- a/lib/GR/Checkers/CStringChecker.cpp
+++ b/lib/GR/Checkers/CStringChecker.cpp
@@ -19,7 +19,7 @@
 #include "llvm/ADT/StringSwitch.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class CStringChecker : public CheckerVisitor<CStringChecker> {
@@ -100,7 +100,7 @@
 } //end anonymous namespace
 
 namespace clang {
-namespace GR {
+namespace ento {
   template <>
   struct GRStateTrait<CStringLength> 
     : public GRStatePartialTrait<CStringLength::EntryMap> {
@@ -109,7 +109,7 @@
 }
 }
 
-void GR::RegisterCStringChecker(ExprEngine &Eng) {
+void ento::RegisterCStringChecker(ExprEngine &Eng) {
   Eng.registerCheck(new CStringChecker());
 }
 
diff --git a/lib/GR/Checkers/CallAndMessageChecker.cpp b/lib/GR/Checkers/CallAndMessageChecker.cpp
index f3306d1..24fc20e 100644
--- a/lib/GR/Checkers/CallAndMessageChecker.cpp
+++ b/lib/GR/Checkers/CallAndMessageChecker.cpp
@@ -19,7 +19,7 @@
 #include "clang/GR/PathSensitive/CheckerVisitor.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class CallAndMessageChecker
@@ -62,7 +62,7 @@
 };
 } // end anonymous namespace
 
-void GR::RegisterCallAndMessageChecker(ExprEngine &Eng) {
+void ento::RegisterCallAndMessageChecker(ExprEngine &Eng) {
   Eng.registerCheck(new CallAndMessageChecker());
 }
 
diff --git a/lib/GR/Checkers/CastSizeChecker.cpp b/lib/GR/Checkers/CastSizeChecker.cpp
index c17dc7a..7844f51 100644
--- a/lib/GR/Checkers/CastSizeChecker.cpp
+++ b/lib/GR/Checkers/CastSizeChecker.cpp
@@ -17,7 +17,7 @@
 #include "ExprEngineInternalChecks.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class CastSizeChecker : public CheckerVisitor<CastSizeChecker> {
@@ -86,6 +86,6 @@
 }
 
 
-void GR::RegisterCastSizeChecker(ExprEngine &Eng) {
+void ento::RegisterCastSizeChecker(ExprEngine &Eng) {
   Eng.registerCheck(new CastSizeChecker());
 }
diff --git a/lib/GR/Checkers/CastToStructChecker.cpp b/lib/GR/Checkers/CastToStructChecker.cpp
index 7b07329..236623f 100644
--- a/lib/GR/Checkers/CastToStructChecker.cpp
+++ b/lib/GR/Checkers/CastToStructChecker.cpp
@@ -18,7 +18,7 @@
 #include "ExprEngineInternalChecks.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class CastToStructChecker 
@@ -74,6 +74,6 @@
   }
 }
 
-void GR::RegisterCastToStructChecker(ExprEngine &Eng) {
+void ento::RegisterCastToStructChecker(ExprEngine &Eng) {
   Eng.registerCheck(new CastToStructChecker());
 }
diff --git a/lib/GR/Checkers/CheckDeadStores.cpp b/lib/GR/Checkers/CheckDeadStores.cpp
index edcf57c..d2ffd6a 100644
--- a/lib/GR/Checkers/CheckDeadStores.cpp
+++ b/lib/GR/Checkers/CheckDeadStores.cpp
@@ -24,7 +24,7 @@
 #include "llvm/ADT/SmallPtrSet.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 
@@ -281,7 +281,7 @@
 } // end anonymous namespace
 
 
-void GR::CheckDeadStores(CFG &cfg, LiveVariables &L, ParentMap &pmap, 
+void ento::CheckDeadStores(CFG &cfg, LiveVariables &L, ParentMap &pmap, 
                             BugReporter& BR) {
   FindEscaped FS(&cfg);
   FS.getCFG().VisitBlockStmts(FS);
diff --git a/lib/GR/Checkers/CheckObjCDealloc.cpp b/lib/GR/Checkers/CheckObjCDealloc.cpp
index f8ec7f6..1aa0249 100644
--- a/lib/GR/Checkers/CheckObjCDealloc.cpp
+++ b/lib/GR/Checkers/CheckObjCDealloc.cpp
@@ -23,7 +23,7 @@
 #include "llvm/Support/raw_ostream.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 static bool scan_dealloc(Stmt* S, Selector Dealloc) {
 
@@ -94,7 +94,7 @@
   return false;
 }
 
-void GR::CheckObjCDealloc(const ObjCImplementationDecl* D,
+void ento::CheckObjCDealloc(const ObjCImplementationDecl* D,
                           const LangOptions& LOpts, BugReporter& BR) {
 
   assert (LOpts.getGCMode() != LangOptions::GCOnly);
diff --git a/lib/GR/Checkers/CheckObjCInstMethSignature.cpp b/lib/GR/Checkers/CheckObjCInstMethSignature.cpp
index b2be375..62c5e60 100644
--- a/lib/GR/Checkers/CheckObjCInstMethSignature.cpp
+++ b/lib/GR/Checkers/CheckObjCInstMethSignature.cpp
@@ -24,7 +24,7 @@
 #include "llvm/Support/raw_ostream.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 static bool AreTypesCompatible(QualType Derived, QualType Ancestor,
                                ASTContext& C) {
@@ -70,7 +70,7 @@
   }
 }
 
-void GR::CheckObjCInstMethSignature(const ObjCImplementationDecl* ID,
+void ento::CheckObjCInstMethSignature(const ObjCImplementationDecl* ID,
                                     BugReporter& BR) {
 
   const ObjCInterfaceDecl* D = ID->getClassInterface();
diff --git a/lib/GR/Checkers/CheckSecuritySyntaxOnly.cpp b/lib/GR/Checkers/CheckSecuritySyntaxOnly.cpp
index ea658e3..bdb03f8 100644
--- a/lib/GR/Checkers/CheckSecuritySyntaxOnly.cpp
+++ b/lib/GR/Checkers/CheckSecuritySyntaxOnly.cpp
@@ -18,7 +18,7 @@
 #include "llvm/Support/raw_ostream.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 static bool isArc4RandomAvailable(const ASTContext &Ctx) {
   const llvm::Triple &T = Ctx.Target.getTriple();
@@ -497,7 +497,7 @@
 // Entry point for check.
 //===----------------------------------------------------------------------===//
 
-void GR::CheckSecuritySyntaxOnly(const Decl *D, BugReporter &BR) {
+void ento::CheckSecuritySyntaxOnly(const Decl *D, BugReporter &BR) {
   WalkAST walker(BR);
   walker.Visit(D->getBody());
 }
diff --git a/lib/GR/Checkers/CheckSizeofPointer.cpp b/lib/GR/Checkers/CheckSizeofPointer.cpp
index 696dce2..3a2e8c7 100644
--- a/lib/GR/Checkers/CheckSizeofPointer.cpp
+++ b/lib/GR/Checkers/CheckSizeofPointer.cpp
@@ -17,7 +17,7 @@
 #include "clang/GR/Checkers/LocalCheckers.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class WalkAST : public StmtVisitor<WalkAST> {
@@ -66,7 +66,7 @@
   }
 }
 
-void GR::CheckSizeofPointer(const Decl *D, BugReporter &BR) {
+void ento::CheckSizeofPointer(const Decl *D, BugReporter &BR) {
   WalkAST walker(BR);
   walker.Visit(D->getBody());
 }
diff --git a/lib/GR/Checkers/ChrootChecker.cpp b/lib/GR/Checkers/ChrootChecker.cpp
index 58b34d0..6a36593 100644
--- a/lib/GR/Checkers/ChrootChecker.cpp
+++ b/lib/GR/Checkers/ChrootChecker.cpp
@@ -19,7 +19,7 @@
 #include "clang/GR/PathSensitive/SymbolManager.h"
 #include "llvm/ADT/ImmutableMap.h"
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 
@@ -59,7 +59,7 @@
 
 } // end anonymous namespace
 
-void GR::RegisterChrootChecker(ExprEngine &Eng) {
+void ento::RegisterChrootChecker(ExprEngine &Eng) {
   Eng.registerCheck(new ChrootChecker());
 }
 
diff --git a/lib/GR/Checkers/DereferenceChecker.cpp b/lib/GR/Checkers/DereferenceChecker.cpp
index dbe0ab3..cecea57 100644
--- a/lib/GR/Checkers/DereferenceChecker.cpp
+++ b/lib/GR/Checkers/DereferenceChecker.cpp
@@ -19,7 +19,7 @@
 #include "clang/GR/PathSensitive/ExprEngine.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class DereferenceChecker : public Checker {
@@ -43,12 +43,12 @@
 };
 } // end anonymous namespace
 
-void GR::RegisterDereferenceChecker(ExprEngine &Eng) {
+void ento::RegisterDereferenceChecker(ExprEngine &Eng) {
   Eng.registerCheck(new DereferenceChecker());
 }
 
 std::pair<ExplodedNode * const *, ExplodedNode * const *>
-GR::GetImplicitNullDereferences(ExprEngine &Eng) {
+ento::GetImplicitNullDereferences(ExprEngine &Eng) {
   DereferenceChecker *checker = Eng.getChecker<DereferenceChecker>();
   if (!checker)
     return std::make_pair((ExplodedNode * const *) 0,
diff --git a/lib/GR/Checkers/DivZeroChecker.cpp b/lib/GR/Checkers/DivZeroChecker.cpp
index 1475a9e..2119a0c 100644
--- a/lib/GR/Checkers/DivZeroChecker.cpp
+++ b/lib/GR/Checkers/DivZeroChecker.cpp
@@ -17,7 +17,7 @@
 #include "clang/GR/PathSensitive/CheckerVisitor.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class DivZeroChecker : public CheckerVisitor<DivZeroChecker> {
@@ -29,7 +29,7 @@
 };  
 } // end anonymous namespace
 
-void GR::RegisterDivZeroChecker(ExprEngine &Eng) {
+void ento::RegisterDivZeroChecker(ExprEngine &Eng) {
   Eng.registerCheck(new DivZeroChecker());
 }
 
diff --git a/lib/GR/Checkers/ExprEngine.cpp b/lib/GR/Checkers/ExprEngine.cpp
index 6e82504..2ff665c 100644
--- a/lib/GR/Checkers/ExprEngine.cpp
+++ b/lib/GR/Checkers/ExprEngine.cpp
@@ -37,7 +37,7 @@
 #endif
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 using llvm::dyn_cast;
 using llvm::dyn_cast_or_null;
 using llvm::cast;
diff --git a/lib/GR/Checkers/ExprEngineExperimentalChecks.cpp b/lib/GR/Checkers/ExprEngineExperimentalChecks.cpp
index d7ad99f..9f3c04a 100644
--- a/lib/GR/Checkers/ExprEngineExperimentalChecks.cpp
+++ b/lib/GR/Checkers/ExprEngineExperimentalChecks.cpp
@@ -17,9 +17,9 @@
 #include "clang/GR/Checkers/LocalCheckers.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
-void GR::RegisterExperimentalChecks(ExprEngine &Eng) {
+void ento::RegisterExperimentalChecks(ExprEngine &Eng) {
   // These are checks that never belong as internal checks
   // within ExprEngine.
   RegisterCStringChecker(Eng);
@@ -30,7 +30,7 @@
   RegisterUnreachableCodeChecker(Eng);
 }
 
-void GR::RegisterExperimentalInternalChecks(ExprEngine &Eng) {
+void ento::RegisterExperimentalInternalChecks(ExprEngine &Eng) {
   // These are internal checks that should eventually migrate to
   // RegisterInternalChecks() once they have been further tested.
   
diff --git a/lib/GR/Checkers/ExprEngineExperimentalChecks.h b/lib/GR/Checkers/ExprEngineExperimentalChecks.h
index 4a04fb9..f8359d1 100644
--- a/lib/GR/Checkers/ExprEngineExperimentalChecks.h
+++ b/lib/GR/Checkers/ExprEngineExperimentalChecks.h
@@ -17,7 +17,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 class ExprEngine;
 
diff --git a/lib/GR/Checkers/ExprEngineInternalChecks.h b/lib/GR/Checkers/ExprEngineInternalChecks.h
index bfb22f5..f67371d 100644
--- a/lib/GR/Checkers/ExprEngineInternalChecks.h
+++ b/lib/GR/Checkers/ExprEngineInternalChecks.h
@@ -17,7 +17,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 class ExprEngine;
 
diff --git a/lib/GR/Checkers/FixedAddressChecker.cpp b/lib/GR/Checkers/FixedAddressChecker.cpp
index d7caad1..1d629ee 100644
--- a/lib/GR/Checkers/FixedAddressChecker.cpp
+++ b/lib/GR/Checkers/FixedAddressChecker.cpp
@@ -18,7 +18,7 @@
 #include "clang/GR/PathSensitive/CheckerVisitor.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class FixedAddressChecker 
@@ -67,6 +67,6 @@
   }
 }
 
-void GR::RegisterFixedAddressChecker(ExprEngine &Eng) {
+void ento::RegisterFixedAddressChecker(ExprEngine &Eng) {
   Eng.registerCheck(new FixedAddressChecker());
 }
diff --git a/lib/GR/Checkers/FrontendActions.cpp b/lib/GR/Checkers/FrontendActions.cpp
index 2097657..c883782 100644
--- a/lib/GR/Checkers/FrontendActions.cpp
+++ b/lib/GR/Checkers/FrontendActions.cpp
@@ -11,7 +11,7 @@
 #include "clang/Frontend/CompilerInstance.h"
 #include "clang/GR/AnalysisConsumer.h"
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 ASTConsumer *AnalysisAction::CreateASTConsumer(CompilerInstance &CI,
                                                llvm::StringRef InFile) {
diff --git a/lib/GR/Checkers/IdempotentOperationChecker.cpp b/lib/GR/Checkers/IdempotentOperationChecker.cpp
index 15e9be9..56bb542 100644
--- a/lib/GR/Checkers/IdempotentOperationChecker.cpp
+++ b/lib/GR/Checkers/IdempotentOperationChecker.cpp
@@ -58,7 +58,7 @@
 #include <deque>
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class IdempotentOperationChecker
@@ -130,7 +130,7 @@
   return &x;
 }
 
-void GR::RegisterIdempotentOperationChecker(ExprEngine &Eng) {
+void ento::RegisterIdempotentOperationChecker(ExprEngine &Eng) {
   Eng.registerCheck(new IdempotentOperationChecker());
 }
 
diff --git a/lib/GR/Checkers/LLVMConventionsChecker.cpp b/lib/GR/Checkers/LLVMConventionsChecker.cpp
index 655e756..864dd85 100644
--- a/lib/GR/Checkers/LLVMConventionsChecker.cpp
+++ b/lib/GR/Checkers/LLVMConventionsChecker.cpp
@@ -20,7 +20,7 @@
 #include "llvm/ADT/StringRef.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 //===----------------------------------------------------------------------===//
 // Generic type checking routines.
@@ -306,7 +306,7 @@
   }
 }
 
-void GR::CheckLLVMConventions(TranslationUnitDecl &TU,
+void ento::CheckLLVMConventions(TranslationUnitDecl &TU,
                                  BugReporter &BR) {
   ScanCodeDecls(&TU, BR);
 }
diff --git a/lib/GR/Checkers/MacOSXAPIChecker.cpp b/lib/GR/Checkers/MacOSXAPIChecker.cpp
index d772871..5934c5f 100644
--- a/lib/GR/Checkers/MacOSXAPIChecker.cpp
+++ b/lib/GR/Checkers/MacOSXAPIChecker.cpp
@@ -25,7 +25,7 @@
 #include "llvm/Support/raw_ostream.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class MacOSXAPIChecker : public CheckerVisitor<MacOSXAPIChecker> {
@@ -45,7 +45,7 @@
 };
 } //end anonymous namespace
 
-void GR::RegisterMacOSXAPIChecker(ExprEngine &Eng) {
+void ento::RegisterMacOSXAPIChecker(ExprEngine &Eng) {
   if (Eng.getContext().Target.getTriple().getVendor() == llvm::Triple::Apple)
     Eng.registerCheck(new MacOSXAPIChecker());
 }
diff --git a/lib/GR/Checkers/MallocChecker.cpp b/lib/GR/Checkers/MallocChecker.cpp
index bbfc7b0..a4d317f 100644
--- a/lib/GR/Checkers/MallocChecker.cpp
+++ b/lib/GR/Checkers/MallocChecker.cpp
@@ -20,7 +20,7 @@
 #include "clang/GR/PathSensitive/SymbolManager.h"
 #include "llvm/ADT/ImmutableMap.h"
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 
@@ -117,7 +117,7 @@
 typedef llvm::ImmutableMap<SymbolRef, RefState> RegionStateTy;
 
 namespace clang {
-namespace GR {
+namespace ento {
   template <>
   struct GRStateTrait<RegionState> 
     : public GRStatePartialTrait<RegionStateTy> {
@@ -126,7 +126,7 @@
 }
 }
 
-void GR::RegisterMallocChecker(ExprEngine &Eng) {
+void ento::RegisterMallocChecker(ExprEngine &Eng) {
   Eng.registerCheck(new MallocChecker());
 }
 
diff --git a/lib/GR/Checkers/NSAutoreleasePoolChecker.cpp b/lib/GR/Checkers/NSAutoreleasePoolChecker.cpp
index beb4a81..c93121f 100644
--- a/lib/GR/Checkers/NSAutoreleasePoolChecker.cpp
+++ b/lib/GR/Checkers/NSAutoreleasePoolChecker.cpp
@@ -23,7 +23,7 @@
 #include "clang/AST/Decl.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class NSAutoreleasePoolChecker
@@ -45,7 +45,7 @@
 } // end anonymous namespace
 
 
-void GR::RegisterNSAutoreleasePoolChecks(ExprEngine &Eng) {
+void ento::RegisterNSAutoreleasePoolChecks(ExprEngine &Eng) {
   ASTContext &Ctx = Eng.getContext();
   if (Ctx.getLangOptions().getGCMode() != LangOptions::NonGC) {    
     Eng.registerCheck(new NSAutoreleasePoolChecker(GetNullarySelector("release",
diff --git a/lib/GR/Checkers/NSErrorChecker.cpp b/lib/GR/Checkers/NSErrorChecker.cpp
index 3cfb044..ee3f901 100644
--- a/lib/GR/Checkers/NSErrorChecker.cpp
+++ b/lib/GR/Checkers/NSErrorChecker.cpp
@@ -25,7 +25,7 @@
 #include "llvm/ADT/SmallVector.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class NSErrorChecker : public BugType {
@@ -63,7 +63,7 @@
 
 } // end anonymous namespace
 
-void GR::RegisterNSErrorChecks(BugReporter& BR, ExprEngine &Eng,
+void ento::RegisterNSErrorChecks(BugReporter& BR, ExprEngine &Eng,
                                   const Decl &D) {
   BR.Register(new NSErrorChecker(D, true, Eng));
   BR.Register(new NSErrorChecker(D, false, Eng));
diff --git a/lib/GR/Checkers/NoReturnFunctionChecker.cpp b/lib/GR/Checkers/NoReturnFunctionChecker.cpp
index f6d33db..ad86ac5 100644
--- a/lib/GR/Checkers/NoReturnFunctionChecker.cpp
+++ b/lib/GR/Checkers/NoReturnFunctionChecker.cpp
@@ -17,7 +17,7 @@
 #include "llvm/ADT/StringSwitch.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 
@@ -29,7 +29,7 @@
 
 }
 
-void GR::RegisterNoReturnFunctionChecker(ExprEngine &Eng) {
+void ento::RegisterNoReturnFunctionChecker(ExprEngine &Eng) {
   Eng.registerCheck(new NoReturnFunctionChecker());
 }
 
diff --git a/lib/GR/Checkers/OSAtomicChecker.cpp b/lib/GR/Checkers/OSAtomicChecker.cpp
index c27e508..3d230ce 100644
--- a/lib/GR/Checkers/OSAtomicChecker.cpp
+++ b/lib/GR/Checkers/OSAtomicChecker.cpp
@@ -16,7 +16,7 @@
 #include "clang/Basic/Builtins.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 
@@ -31,7 +31,7 @@
 
 }
 
-void GR::RegisterOSAtomicChecker(ExprEngine &Eng) {
+void ento::RegisterOSAtomicChecker(ExprEngine &Eng) {
   Eng.registerCheck(new OSAtomicChecker());
 }
 
diff --git a/lib/GR/Checkers/ObjCAtSyncChecker.cpp b/lib/GR/Checkers/ObjCAtSyncChecker.cpp
index 40619a2..b44fae8 100644
--- a/lib/GR/Checkers/ObjCAtSyncChecker.cpp
+++ b/lib/GR/Checkers/ObjCAtSyncChecker.cpp
@@ -19,7 +19,7 @@
 #include "clang/GR/PathSensitive/ExprEngine.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class ObjCAtSyncChecker : public CheckerVisitor<ObjCAtSyncChecker> {
@@ -33,7 +33,7 @@
 };
 } // end anonymous namespace
 
-void GR::RegisterObjCAtSyncChecker(ExprEngine &Eng) {
+void ento::RegisterObjCAtSyncChecker(ExprEngine &Eng) {
   // @synchronized is an Objective-C 2 feature.
   if (Eng.getContext().getLangOptions().ObjC2)
     Eng.registerCheck(new ObjCAtSyncChecker());
diff --git a/lib/GR/Checkers/ObjCUnusedIVarsChecker.cpp b/lib/GR/Checkers/ObjCUnusedIVarsChecker.cpp
index 611914f..177f6a2 100644
--- a/lib/GR/Checkers/ObjCUnusedIVarsChecker.cpp
+++ b/lib/GR/Checkers/ObjCUnusedIVarsChecker.cpp
@@ -23,7 +23,7 @@
 #include "clang/Basic/SourceManager.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 enum IVarState { Unused, Used };
 typedef llvm::DenseMap<const ObjCIvarDecl*,IVarState> IvarUsageMap;
@@ -98,7 +98,7 @@
     }
 }
 
-void GR::CheckObjCUnusedIvar(const ObjCImplementationDecl *D,
+void ento::CheckObjCUnusedIvar(const ObjCImplementationDecl *D,
                                 BugReporter &BR) {
 
   const ObjCInterfaceDecl* ID = D->getClassInterface();
diff --git a/lib/GR/Checkers/PointerArithChecker.cpp b/lib/GR/Checkers/PointerArithChecker.cpp
index 1f87005..f40eeec 100644
--- a/lib/GR/Checkers/PointerArithChecker.cpp
+++ b/lib/GR/Checkers/PointerArithChecker.cpp
@@ -17,7 +17,7 @@
 #include "clang/GR/PathSensitive/CheckerVisitor.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class PointerArithChecker 
@@ -67,6 +67,6 @@
   }
 }
 
-void GR::RegisterPointerArithChecker(ExprEngine &Eng) {
+void ento::RegisterPointerArithChecker(ExprEngine &Eng) {
   Eng.registerCheck(new PointerArithChecker());
 }
diff --git a/lib/GR/Checkers/PointerSubChecker.cpp b/lib/GR/Checkers/PointerSubChecker.cpp
index 57ab318..63aa904 100644
--- a/lib/GR/Checkers/PointerSubChecker.cpp
+++ b/lib/GR/Checkers/PointerSubChecker.cpp
@@ -18,7 +18,7 @@
 #include "clang/GR/PathSensitive/CheckerVisitor.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class PointerSubChecker 
@@ -74,6 +74,6 @@
   }
 }
 
-void GR::RegisterPointerSubChecker(ExprEngine &Eng) {
+void ento::RegisterPointerSubChecker(ExprEngine &Eng) {
   Eng.registerCheck(new PointerSubChecker());
 }
diff --git a/lib/GR/Checkers/PthreadLockChecker.cpp b/lib/GR/Checkers/PthreadLockChecker.cpp
index ae58b78..517f6b1 100644
--- a/lib/GR/Checkers/PthreadLockChecker.cpp
+++ b/lib/GR/Checkers/PthreadLockChecker.cpp
@@ -19,7 +19,7 @@
 #include "llvm/ADT/ImmutableSet.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class PthreadLockChecker
@@ -45,7 +45,7 @@
 // GDM Entry for tracking lock state.
 namespace { class LockSet {}; }
 namespace clang {
-namespace GR {
+namespace ento {
 template <> struct GRStateTrait<LockSet> :
   public GRStatePartialTrait<llvm::ImmutableSet<const MemRegion*> > {
     static void* GDMIndex() { return PthreadLockChecker::getTag(); }
@@ -53,7 +53,7 @@
 } // end GR namespace
 } // end clang namespace
 
-void GR::RegisterPthreadLockChecker(ExprEngine &Eng) {
+void ento::RegisterPthreadLockChecker(ExprEngine &Eng) {
   Eng.registerCheck(new PthreadLockChecker());
 }
 
diff --git a/lib/GR/Checkers/ReturnPointerRangeChecker.cpp b/lib/GR/Checkers/ReturnPointerRangeChecker.cpp
index 4ef5737f..80316f5 100644
--- a/lib/GR/Checkers/ReturnPointerRangeChecker.cpp
+++ b/lib/GR/Checkers/ReturnPointerRangeChecker.cpp
@@ -18,7 +18,7 @@
 #include "clang/GR/PathSensitive/ExprEngine.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class ReturnPointerRangeChecker : 
@@ -31,7 +31,7 @@
 };
 }
 
-void GR::RegisterReturnPointerRangeChecker(ExprEngine &Eng) {
+void ento::RegisterReturnPointerRangeChecker(ExprEngine &Eng) {
   Eng.registerCheck(new ReturnPointerRangeChecker());
 }
 
diff --git a/lib/GR/Checkers/ReturnUndefChecker.cpp b/lib/GR/Checkers/ReturnUndefChecker.cpp
index 2a1027a..17a2a55 100644
--- a/lib/GR/Checkers/ReturnUndefChecker.cpp
+++ b/lib/GR/Checkers/ReturnUndefChecker.cpp
@@ -19,7 +19,7 @@
 #include "clang/GR/PathSensitive/ExprEngine.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class ReturnUndefChecker : 
@@ -32,7 +32,7 @@
 };
 }
 
-void GR::RegisterReturnUndefChecker(ExprEngine &Eng) {
+void ento::RegisterReturnUndefChecker(ExprEngine &Eng) {
   Eng.registerCheck(new ReturnUndefChecker());
 }
 
diff --git a/lib/GR/Checkers/StackAddrLeakChecker.cpp b/lib/GR/Checkers/StackAddrLeakChecker.cpp
index 3ef78a4..229356a 100644
--- a/lib/GR/Checkers/StackAddrLeakChecker.cpp
+++ b/lib/GR/Checkers/StackAddrLeakChecker.cpp
@@ -19,7 +19,7 @@
 #include "clang/Basic/SourceManager.h"
 #include "llvm/ADT/SmallString.h"
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class StackAddrLeakChecker : public CheckerVisitor<StackAddrLeakChecker> {
@@ -41,7 +41,7 @@
 };
 }
 
-void GR::RegisterStackAddrLeakChecker(ExprEngine &Eng) {
+void ento::RegisterStackAddrLeakChecker(ExprEngine &Eng) {
   Eng.registerCheck(new StackAddrLeakChecker());
 }
 
diff --git a/lib/GR/Checkers/StreamChecker.cpp b/lib/GR/Checkers/StreamChecker.cpp
index 73c2920..32e22b0 100644
--- a/lib/GR/Checkers/StreamChecker.cpp
+++ b/lib/GR/Checkers/StreamChecker.cpp
@@ -20,7 +20,7 @@
 #include "llvm/ADT/ImmutableMap.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 
@@ -105,7 +105,7 @@
 } // end anonymous namespace
 
 namespace clang {
-namespace GR {
+namespace ento {
   template <>
   struct GRStateTrait<StreamState> 
     : public GRStatePartialTrait<llvm::ImmutableMap<SymbolRef, StreamState> > {
@@ -114,7 +114,7 @@
 }
 }
 
-void GR::RegisterStreamChecker(ExprEngine &Eng) {
+void ento::RegisterStreamChecker(ExprEngine &Eng) {
   Eng.registerCheck(new StreamChecker());
 }
 
diff --git a/lib/GR/Checkers/UndefBranchChecker.cpp b/lib/GR/Checkers/UndefBranchChecker.cpp
index e999d8b..fc668be 100644
--- a/lib/GR/Checkers/UndefBranchChecker.cpp
+++ b/lib/GR/Checkers/UndefBranchChecker.cpp
@@ -17,7 +17,7 @@
 #include "clang/GR/PathSensitive/Checker.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 
@@ -56,7 +56,7 @@
 
 }
 
-void GR::RegisterUndefBranchChecker(ExprEngine &Eng) {
+void ento::RegisterUndefBranchChecker(ExprEngine &Eng) {
   Eng.registerCheck(new UndefBranchChecker());
 }
 
diff --git a/lib/GR/Checkers/UndefCapturedBlockVarChecker.cpp b/lib/GR/Checkers/UndefCapturedBlockVarChecker.cpp
index 2b45c95..8ceda3d 100644
--- a/lib/GR/Checkers/UndefCapturedBlockVarChecker.cpp
+++ b/lib/GR/Checkers/UndefCapturedBlockVarChecker.cpp
@@ -18,7 +18,7 @@
 #include "llvm/Support/raw_ostream.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class UndefCapturedBlockVarChecker
@@ -32,7 +32,7 @@
 };
 } // end anonymous namespace
 
-void GR::RegisterUndefCapturedBlockVarChecker(ExprEngine &Eng) {
+void ento::RegisterUndefCapturedBlockVarChecker(ExprEngine &Eng) {
   Eng.registerCheck(new UndefCapturedBlockVarChecker());
 }
 
diff --git a/lib/GR/Checkers/UndefResultChecker.cpp b/lib/GR/Checkers/UndefResultChecker.cpp
index 348573d..3d4faa2 100644
--- a/lib/GR/Checkers/UndefResultChecker.cpp
+++ b/lib/GR/Checkers/UndefResultChecker.cpp
@@ -18,7 +18,7 @@
 #include "clang/GR/PathSensitive/ExprEngine.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class UndefResultChecker 
@@ -33,7 +33,7 @@
 };
 } // end anonymous namespace
 
-void GR::RegisterUndefResultChecker(ExprEngine &Eng) {
+void ento::RegisterUndefResultChecker(ExprEngine &Eng) {
   Eng.registerCheck(new UndefResultChecker());
 }
 
diff --git a/lib/GR/Checkers/UndefinedArraySubscriptChecker.cpp b/lib/GR/Checkers/UndefinedArraySubscriptChecker.cpp
index 0a3cee4..90f7d5d 100644
--- a/lib/GR/Checkers/UndefinedArraySubscriptChecker.cpp
+++ b/lib/GR/Checkers/UndefinedArraySubscriptChecker.cpp
@@ -17,7 +17,7 @@
 #include "clang/GR/PathSensitive/CheckerVisitor.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class UndefinedArraySubscriptChecker
@@ -34,7 +34,7 @@
 };
 } // end anonymous namespace
 
-void GR::RegisterUndefinedArraySubscriptChecker(ExprEngine &Eng) {
+void ento::RegisterUndefinedArraySubscriptChecker(ExprEngine &Eng) {
   Eng.registerCheck(new UndefinedArraySubscriptChecker());
 }
 
diff --git a/lib/GR/Checkers/UndefinedAssignmentChecker.cpp b/lib/GR/Checkers/UndefinedAssignmentChecker.cpp
index fa43350..8addd44 100644
--- a/lib/GR/Checkers/UndefinedAssignmentChecker.cpp
+++ b/lib/GR/Checkers/UndefinedAssignmentChecker.cpp
@@ -17,7 +17,7 @@
 #include "clang/GR/PathSensitive/CheckerVisitor.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class UndefinedAssignmentChecker
@@ -31,7 +31,7 @@
 };
 }
 
-void GR::RegisterUndefinedAssignmentChecker(ExprEngine &Eng){
+void ento::RegisterUndefinedAssignmentChecker(ExprEngine &Eng){
   Eng.registerCheck(new UndefinedAssignmentChecker());
 }
 
diff --git a/lib/GR/Checkers/UnixAPIChecker.cpp b/lib/GR/Checkers/UnixAPIChecker.cpp
index c365e30..b9d8b57 100644
--- a/lib/GR/Checkers/UnixAPIChecker.cpp
+++ b/lib/GR/Checkers/UnixAPIChecker.cpp
@@ -21,7 +21,7 @@
 #include <fcntl.h>
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 using llvm::Optional;
 
 namespace {
@@ -46,7 +46,7 @@
 };
 } //end anonymous namespace
 
-void GR::RegisterUnixAPIChecker(ExprEngine &Eng) {
+void ento::RegisterUnixAPIChecker(ExprEngine &Eng) {
   Eng.registerCheck(new UnixAPIChecker());
 }
 
diff --git a/lib/GR/Checkers/UnreachableCodeChecker.cpp b/lib/GR/Checkers/UnreachableCodeChecker.cpp
index 97a2ff5..b52dc87 100644
--- a/lib/GR/Checkers/UnreachableCodeChecker.cpp
+++ b/lib/GR/Checkers/UnreachableCodeChecker.cpp
@@ -29,7 +29,7 @@
 #define DEFAULT_CFGBLOCKS 256
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class UnreachableCodeChecker : public Checker {
@@ -54,7 +54,7 @@
   return &x;
 }
 
-void GR::RegisterUnreachableCodeChecker(ExprEngine &Eng) {
+void ento::RegisterUnreachableCodeChecker(ExprEngine &Eng) {
   Eng.registerCheck(new UnreachableCodeChecker());
 }
 
diff --git a/lib/GR/Checkers/VLASizeChecker.cpp b/lib/GR/Checkers/VLASizeChecker.cpp
index b2ca2db..d21ad21 100644
--- a/lib/GR/Checkers/VLASizeChecker.cpp
+++ b/lib/GR/Checkers/VLASizeChecker.cpp
@@ -21,7 +21,7 @@
 #include "clang/GR/PathSensitive/ExprEngine.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class VLASizeChecker : public CheckerVisitor<VLASizeChecker> {
@@ -35,7 +35,7 @@
 };
 } // end anonymous namespace
 
-void GR::RegisterVLASizeChecker(ExprEngine &Eng) {
+void ento::RegisterVLASizeChecker(ExprEngine &Eng) {
   Eng.registerCheck(new VLASizeChecker());
 }
 
diff --git a/lib/GR/CoreEngine.cpp b/lib/GR/CoreEngine.cpp
index a086c91..3236b92 100644
--- a/lib/GR/CoreEngine.cpp
+++ b/lib/GR/CoreEngine.cpp
@@ -25,11 +25,11 @@
 using llvm::cast;
 using llvm::isa;
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 // This should be removed in the future.
 namespace clang {
-namespace GR {
+namespace ento {
 TransferFuncs* MakeCFRefCountTF(ASTContext& Ctx, bool GCEnabled,
                                   const LangOptions& lopts);
 }
diff --git a/lib/GR/Environment.cpp b/lib/GR/Environment.cpp
index 74ac7f2..4961704 100644
--- a/lib/GR/Environment.cpp
+++ b/lib/GR/Environment.cpp
@@ -16,7 +16,7 @@
 #include "clang/GR/PathSensitive/GRState.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 SVal Environment::lookupExpr(const Stmt* E) const {
   const SVal* X = ExprBindings.lookup(E);
diff --git a/lib/GR/ExplodedGraph.cpp b/lib/GR/ExplodedGraph.cpp
index fc46813..dd206ab 100644
--- a/lib/GR/ExplodedGraph.cpp
+++ b/lib/GR/ExplodedGraph.cpp
@@ -21,7 +21,7 @@
 #include <vector>
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 //===----------------------------------------------------------------------===//
 // Node auditing.
diff --git a/lib/GR/FlatStore.cpp b/lib/GR/FlatStore.cpp
index d4bd4b8..6809c3b 100644
--- a/lib/GR/FlatStore.cpp
+++ b/lib/GR/FlatStore.cpp
@@ -12,7 +12,7 @@
 #include "llvm/Support/ErrorHandling.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 using llvm::Interval;
 
 // The actual store type.
@@ -84,7 +84,7 @@
 };
 } // end anonymous namespace
 
-StoreManager *GR::CreateFlatStoreManager(GRStateManager &StMgr) {
+StoreManager *ento::CreateFlatStoreManager(GRStateManager &StMgr) {
   return new FlatStoreManager(StMgr);
 }
 
diff --git a/lib/GR/GRState.cpp b/lib/GR/GRState.cpp
index 3a4c15a..e531cc9 100644
--- a/lib/GR/GRState.cpp
+++ b/lib/GR/GRState.cpp
@@ -19,7 +19,7 @@
 #include "llvm/Support/raw_ostream.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 // Give the vtable for ConstraintManager somewhere to live.
 // FIXME: Move this elsewhere.
diff --git a/lib/GR/HTMLDiagnostics.cpp b/lib/GR/HTMLDiagnostics.cpp
index 0c059ff..72a854a 100644
--- a/lib/GR/HTMLDiagnostics.cpp
+++ b/lib/GR/HTMLDiagnostics.cpp
@@ -26,7 +26,7 @@
 #include "llvm/Support/Path.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 //===----------------------------------------------------------------------===//
 // Boilerplate.
@@ -78,8 +78,8 @@
 }
 
 PathDiagnosticClient*
-GR::createHTMLDiagnosticClient(const std::string& prefix,
-                                  const Preprocessor &PP) {
+ento::createHTMLDiagnosticClient(const std::string& prefix,
+                                 const Preprocessor &PP) {
   return new HTMLDiagnostics(prefix, PP);
 }
 
diff --git a/lib/GR/ManagerRegistry.cpp b/lib/GR/ManagerRegistry.cpp
index ab3a0a1..4058c11 100644
--- a/lib/GR/ManagerRegistry.cpp
+++ b/lib/GR/ManagerRegistry.cpp
@@ -14,7 +14,7 @@
 #include "clang/GR/ManagerRegistry.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 StoreManagerCreator ManagerRegistry::StoreMgrCreator = 0;
 
diff --git a/lib/GR/MemRegion.cpp b/lib/GR/MemRegion.cpp
index fd8ab6a..f162236 100644
--- a/lib/GR/MemRegion.cpp
+++ b/lib/GR/MemRegion.cpp
@@ -22,7 +22,7 @@
 #include "llvm/Support/raw_ostream.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 //===----------------------------------------------------------------------===//
 // MemRegion Construction.
diff --git a/lib/GR/PathDiagnostic.cpp b/lib/GR/PathDiagnostic.cpp
index b496560..69c660b 100644
--- a/lib/GR/PathDiagnostic.cpp
+++ b/lib/GR/PathDiagnostic.cpp
@@ -20,7 +20,7 @@
 #include "llvm/Support/Casting.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 using llvm::dyn_cast;
 using llvm::isa;
 
diff --git a/lib/GR/PlistDiagnostics.cpp b/lib/GR/PlistDiagnostics.cpp
index 35a46bf..ebab2b2 100644
--- a/lib/GR/PlistDiagnostics.cpp
+++ b/lib/GR/PlistDiagnostics.cpp
@@ -21,7 +21,7 @@
 #include "llvm/ADT/DenseMap.h"
 #include "llvm/ADT/SmallVector.h"
 using namespace clang;
-using namespace GR;
+using namespace ento;
 using llvm::cast;
 
 typedef llvm::DenseMap<FileID, unsigned> FIDMap;
@@ -98,8 +98,8 @@
   : OutputFile(output), LangOpts(LO), SubPD(subPD), flushed(false) {}
 
 PathDiagnosticClient*
-GR::createPlistDiagnosticClient(const std::string& s, const Preprocessor &PP,
-                                   PathDiagnosticClient *subPD) {
+ento::createPlistDiagnosticClient(const std::string& s, const Preprocessor &PP,
+                                  PathDiagnosticClient *subPD) {
   return new PlistDiagnostics(s, PP.getLangOptions(), subPD);
 }
 
diff --git a/lib/GR/RangeConstraintManager.cpp b/lib/GR/RangeConstraintManager.cpp
index 8f8528d..5ce69ba 100644
--- a/lib/GR/RangeConstraintManager.cpp
+++ b/lib/GR/RangeConstraintManager.cpp
@@ -23,7 +23,7 @@
 #include "llvm/Support/raw_ostream.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace { class ConstraintRange {}; }
 static int ConstraintRangeIndex = 0;
@@ -195,7 +195,7 @@
 typedef llvm::ImmutableMap<SymbolRef,RangeSet> ConstraintRangeTy;
 
 namespace clang {
-namespace GR {
+namespace ento {
 template<>
 struct GRStateTrait<ConstraintRange>
   : public GRStatePartialTrait<ConstraintRangeTy> {
@@ -254,7 +254,7 @@
 
 } // end anonymous namespace
 
-ConstraintManager* GR::CreateRangeConstraintManager(GRStateManager&,
+ConstraintManager* ento::CreateRangeConstraintManager(GRStateManager&,
                                                     SubEngine &subeng) {
   return new RangeConstraintManager(subeng);
 }
diff --git a/lib/GR/RegionStore.cpp b/lib/GR/RegionStore.cpp
index 2fa8a97..0ae68cf 100644
--- a/lib/GR/RegionStore.cpp
+++ b/lib/GR/RegionStore.cpp
@@ -29,7 +29,7 @@
 #include "llvm/Support/raw_ostream.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 using llvm::Optional;
 
 //===----------------------------------------------------------------------===//
@@ -404,12 +404,12 @@
 // RegionStore creation.
 //===----------------------------------------------------------------------===//
 
-StoreManager *GR::CreateRegionStoreManager(GRStateManager& StMgr) {
+StoreManager *ento::CreateRegionStoreManager(GRStateManager& StMgr) {
   RegionStoreFeatures F = maximal_features_tag();
   return new RegionStoreManager(StMgr, F);
 }
 
-StoreManager *GR::CreateFieldsOnlyRegionStoreManager(GRStateManager &StMgr) {
+StoreManager *ento::CreateFieldsOnlyRegionStoreManager(GRStateManager &StMgr) {
   RegionStoreFeatures F = minimal_features_tag();
   F.enableFields(true);
   return new RegionStoreManager(StMgr, F);
diff --git a/lib/GR/SValBuilder.cpp b/lib/GR/SValBuilder.cpp
index daff8dd..eec5193 100644
--- a/lib/GR/SValBuilder.cpp
+++ b/lib/GR/SValBuilder.cpp
@@ -19,7 +19,7 @@
 #include "clang/GR/PathSensitive/BasicValueFactory.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 //===----------------------------------------------------------------------===//
 // Basic SVal creation.
diff --git a/lib/GR/SVals.cpp b/lib/GR/SVals.cpp
index 0484b62..ed2bc13 100644
--- a/lib/GR/SVals.cpp
+++ b/lib/GR/SVals.cpp
@@ -16,7 +16,7 @@
 #include "clang/Basic/IdentifierTable.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 using llvm::dyn_cast;
 using llvm::cast;
 using llvm::APSInt;
diff --git a/lib/GR/SimpleConstraintManager.h b/lib/GR/SimpleConstraintManager.h
index 6163693..85d133f 100644
--- a/lib/GR/SimpleConstraintManager.h
+++ b/lib/GR/SimpleConstraintManager.h
@@ -19,7 +19,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 class SimpleConstraintManager : public ConstraintManager {
   SubEngine &SU;
diff --git a/lib/GR/SimpleSValBuilder.cpp b/lib/GR/SimpleSValBuilder.cpp
index 2fc2347..bcd303e 100644
--- a/lib/GR/SimpleSValBuilder.cpp
+++ b/lib/GR/SimpleSValBuilder.cpp
@@ -15,7 +15,7 @@
 #include "clang/GR/PathSensitive/GRState.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 namespace {
 class SimpleSValBuilder : public SValBuilder {
@@ -47,9 +47,9 @@
 };
 } // end anonymous namespace
 
-SValBuilder *GR::createSimpleSValBuilder(llvm::BumpPtrAllocator &alloc,
-                                            ASTContext &context,
-                                            GRStateManager &stateMgr) {
+SValBuilder *ento::createSimpleSValBuilder(llvm::BumpPtrAllocator &alloc,
+                                           ASTContext &context,
+                                           GRStateManager &stateMgr) {
   return new SimpleSValBuilder(alloc, context, stateMgr);
 }
 
diff --git a/lib/GR/Store.cpp b/lib/GR/Store.cpp
index 99c06e4..2e9857a 100644
--- a/lib/GR/Store.cpp
+++ b/lib/GR/Store.cpp
@@ -16,7 +16,7 @@
 #include "clang/AST/CharUnits.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 StoreManager::StoreManager(GRStateManager &stateMgr)
   : svalBuilder(stateMgr.getSValBuilder()), StateMgr(stateMgr),
diff --git a/lib/GR/SymbolManager.cpp b/lib/GR/SymbolManager.cpp
index 6d078f4..7727138 100644
--- a/lib/GR/SymbolManager.cpp
+++ b/lib/GR/SymbolManager.cpp
@@ -18,7 +18,7 @@
 #include "llvm/Support/raw_ostream.h"
 
 using namespace clang;
-using namespace GR;
+using namespace ento;
 
 void SymExpr::dump() const {
   dumpToStream(llvm::errs());
diff --git a/lib/GR/TextPathDiagnostics.cpp b/lib/GR/TextPathDiagnostics.cpp
index c7a9f56..02e6c2e 100644
--- a/lib/GR/TextPathDiagnostics.cpp
+++ b/lib/GR/TextPathDiagnostics.cpp
@@ -16,7 +16,7 @@
 #include "clang/Lex/Preprocessor.h"
 #include "llvm/Support/raw_ostream.h"
 using namespace clang;
-using namespace GR;
+using namespace ento;
 using namespace llvm;
 
 namespace {
@@ -48,8 +48,8 @@
 } // end anonymous namespace
 
 PathDiagnosticClient*
-GR::createTextPathDiagnosticClient(const std::string& out,
-                                      const Preprocessor &PP) {
+ento::createTextPathDiagnosticClient(const std::string& out,
+                                     const Preprocessor &PP) {
   return new TextPathDiagnostics(out, PP.getDiagnostics());
 }
diff --git a/include/clang/GR/PathSensitive/SVals.h b/include/clang/GR/PathSensitive/SVals.h
index 2081461..617b394 100644
--- a/include/clang/GR/PathSensitive/SVals.h
+++ b/include/clang/GR/PathSensitive/SVals.h
@@ -29,7 +29,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 class CompoundValData;
 class LazyCompoundValData;
@@ -342,7 +342,7 @@
 };
 
 class LocAsInteger : public NonLoc {
-  friend class GR::SValBuilder;
+  friend class ento::SValBuilder;
 
   explicit LocAsInteger(const std::pair<SVal, uintptr_t>& data) :
     NonLoc(LocAsIntegerKind, &data) {
@@ -376,7 +376,7 @@
 };
 
 class CompoundVal : public NonLoc {
-  friend class GR::SValBuilder;
+  friend class ento::SValBuilder;
 
   explicit CompoundVal(const CompoundValData* D) : NonLoc(CompoundValKind, D) {}
 
@@ -399,7 +399,7 @@
 };
 
 class LazyCompoundVal : public NonLoc {
-  friend class GR::SValBuilder;
+  friend class ento::SValBuilder;
 
   explicit LazyCompoundVal(const LazyCompoundValData *D)
     : NonLoc(LazyCompoundValKind, D) {}
@@ -419,7 +419,7 @@
   }
 };
 
-} // end namespace GR::nonloc
+} // end namespace ento::nonloc
 
 //==------------------------------------------------------------------------==//
 //  Subclasses of Loc.
@@ -505,14 +505,14 @@
   }
 };
 
-} // end GR::loc namespace
+} // end ento::loc namespace
 } // end GR namespace
 
 } // end clang namespace
 
 namespace llvm {
 static inline llvm::raw_ostream& operator<<(llvm::raw_ostream& os,
-                                            clang::GR::SVal V) {
+                                            clang::ento::SVal V) {
   V.dumpToStream(os);
   return os;
 }
diff --git a/lib/GR/SimpleConstraintManager.cpp b/lib/GR/SimpleConstraintManager.cpp
index 83e7955..f0d50da 100644
--- a/lib/GR/SimpleConstraintManager.cpp
+++ b/lib/GR/SimpleConstraintManager.cpp
@@ -19,7 +19,7 @@
 
 namespace clang {
 
-namespace GR {
+namespace ento {
 
 SimpleConstraintManager::~SimpleConstraintManager() {}
 
@@ -298,6 +298,6 @@
   } // end switch
 }
 
-} // end of namespace GR
+} // end of namespace ento
 
 } // end of namespace clang